@@ -10,9 +10,8 @@ from logging import error, info, warning
 from typing import Dict, List, Optional, Text, Union
 
 import act.api
-from act.api.helpers import Act, handle_fact
+from act.api.helpers import Act, handle_fact, handle_facts
 from act.api.libs import cli
-from act.types.format import ValidationError, format_threat_actor, format_tool
 from pyattck import Attck
 
 from act.workers.libs import worker
@@ -170,45 +169,38 @@ def add_groups(
                 handle_fact(
                     client.fact("alias").bidirectional(
                         "threatActor",
-                        format_threat_actor(actor.name),
+                        actor.name,
                         "threatActor",
-                        format_threat_actor(alias),
+                        alias,
                     ),
                     output_format=output_format,
                 )
 
         for tool in actor.known_tools:
 
-            try:
-                chain = act.api.fact.fact_chain(
+            handle_facts(
+                act.api.fact.fact_chain(
                     client.fact("classifiedAs")
                     .source("content", "*")
-                    .destination("tool", format_tool(tool)),
+                    .destination("tool", tool),
                     client.fact("observedIn")
                     .source("content", "*")
                     .destination("incident", "*"),
                     client.fact("attributedTo")
                     .source("incident", "*")
-                    .destination("threatActor", format_threat_actor(actor.name)),
-                )
-
-                for fact in chain:
-                    handle_fact(fact, output_format=output_format)
-            except ValidationError as e:
-                error(e)
+                    .destination("threatActor", actor.name),
+                ) , output_format=output_format)
 
         for technique in actor.techniques:
-            chain = act.api.fact.fact_chain(
-                client.fact("observedIn")
-                .source("technique", technique.id)
-                .destination("incident", "*"),
-                client.fact("attributedTo")
-                .source("incident", "*")
-                .destination("threatActor", format_threat_actor(actor.name)),
-            )
-
-            for fact in chain:
-                handle_fact(fact, output_format=output_format)
+            handle_facts(
+                act.api.fact.fact_chain(
+                    client.fact("observedIn")
+                    .source("technique", technique.id)
+                    .destination("incident", "*"),
+                    client.fact("attributedTo")
+                    .source("incident", "*")
+                    .destination("threatActor", actor.name),
+                ), output_format=output_format)
 
     return notify
 
@@ -235,11 +227,7 @@ def add_software(
             notify.append(software)
             continue
 
-        try:
-            tool_name = format_tool(software.name)
-        except ValidationError as e:
-            error(e)
-            continue
+        tool_name = software.name
 
         # Tool category
         handle_fact(
@@ -248,11 +236,7 @@ def add_software(
         )
 
         for alias in software.alias:
-            try:
-                alias_name = format_tool(alias)
-            except ValidationError as e:
-                error(e)
-                continue
+            alias_name = alias
 
             if tool_name != alias_name:
                 # Tool category (alias)
@@ -268,16 +252,12 @@ def add_software(
                 )
 
         for technique in software.techniques:
-            try:
-                handle_fact(
-                    client.fact("implements")
-                    .source("tool", format_tool(software.name))
-                    .destination("technique", technique.id),
-                    output_format=output_format,
-                )
-            except ValidationError as e:
-                error(e)
-                continue
+            handle_fact(
+                client.fact("implements")
+                .source("tool", software.name)
+                .destination("technique", technique.id),
+                output_format=output_format,
+            )
 
     return notify
 
